@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2008-2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2008–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -60,6 +60,7 @@ struct _GDataFeedPrivate {
 	GTimeVal updated;
 	GList *categories; /* GDataCategory */
 	gchar *logo;
+	gchar *icon;
 	GList *links; /* GDataLink */
 	GList *authors; /* GDataAuthor */
 	GDataGenerator *generator;
@@ -75,6 +76,7 @@ enum {
 	PROP_TITLE,
 	PROP_SUBTITLE,
 	PROP_LOGO,
+	PROP_ICON,
 	PROP_GENERATOR,
 	PROP_ITEMS_PER_PAGE,
 	PROP_START_INDEX,
@@ -155,7 +157,6 @@ gdata_feed_class_init (GDataFeedClass *klass)
 					NULL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
-
 	/**
 	 * GDataFeed:updated:
 	 *
@@ -183,6 +184,21 @@ gdata_feed_class_init (GDataFeedClass *klass)
 					NULL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
+	/**
+	 * GDataFeed:icon:
+	 *
+	 * The URI of an icon for the feed.
+	 *
+	 * API reference: <ulink type="http" url="http://www.atomenabled.org/developers/syndication/atom-format-spec.php#element.icon">atom:icon</ulink>
+	 *
+	 * Since: 0.6.0
+	 **/
+	g_object_class_install_property (gobject_class, PROP_ICON,
+					 g_param_spec_string ("icon",
+							      "Icon", "The URI of an icon for the feed.",
+							      NULL,
+							      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
 	/**
 	 * GDataFeed:generator:
 	 *
@@ -294,11 +310,12 @@ gdata_feed_finalize (GObject *object)
 {
 	GDataFeedPrivate *priv = GDATA_FEED (object)->priv;
 
-	xmlFree (priv->title);
-	xmlFree (priv->subtitle);
-	xmlFree (priv->id);
-	xmlFree (priv->etag);
-	xmlFree (priv->logo);
+	g_free (priv->title);
+	g_free (priv->subtitle);
+	g_free (priv->id);
+	g_free (priv->etag);
+	g_free (priv->logo);
+	g_free (priv->icon);
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_feed_parent_class)->finalize (object);
@@ -328,6 +345,9 @@ gdata_feed_get_property (GObject *object, guint property_id, GValue *value, GPar
 		case PROP_LOGO:
 			g_value_set_string (value, priv->logo);
 			break;
+		case PROP_ICON:
+			g_value_set_string (value, priv->icon);
+			break;
 		case PROP_GENERATOR:
 			g_value_set_object (value, priv->generator);
 			break;
@@ -389,11 +409,19 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 
 	if (xmlStrcmp (node->name, (xmlChar*) "entry") == 0) {
 		/* atom:entry */
-		GDataEntry *entry = GDATA_ENTRY (_gdata_parsable_new_from_xml_node (data->entry_type, doc, node, NULL, error));
+		GDataEntry *entry;
+		GType entry_type;
+
+		/* Allow @data to be %NULL, and assume we're parsing a vanilla feed, so that we can test #GDataFeed in tests/general.c. A little hacky,
+		 * but not too much so, and valuable for testing. */
+		entry_type = (data != NULL) ? data->entry_type : GDATA_TYPE_ENTRY;
+		entry = GDATA_ENTRY (_gdata_parsable_new_from_xml_node (entry_type, doc, node, NULL, error));
 		if (entry == NULL)
 			return FALSE;
-		/*calls the callbacks in the main thread*/
-		_gdata_feed_call_progress_callback (self, data, entry);
+
+		/* Calls the callbacks in the main thread */
+		if (data != NULL)
+			_gdata_feed_call_progress_callback (self, data, entry);
 		_gdata_feed_add_entry (self, entry);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "title") == 0) {
 		/* atom:title */
@@ -429,7 +457,6 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			xmlFree (updated_string);
 			return FALSE;
 		}
-
 		xmlFree (updated_string);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "category") == 0) {
 		/* atom:category */
@@ -444,6 +471,12 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			return gdata_parser_error_duplicate_element (node, error);
 
 		self->priv->logo = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
+	} else if (xmlStrcmp (node->name, (xmlChar*) "icon") == 0) {
+		/* atom:icon */
+		if (self->priv->icon != NULL)
+			return gdata_parser_error_duplicate_element (node, error);
+
+		self->priv->icon = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "link") == 0) {
 		/* atom:link */
 		GDataLink *link = GDATA_LINK (_gdata_parsable_new_from_xml_node (GDATA_TYPE_LINK, doc, node, NULL, error));
@@ -548,20 +581,19 @@ post_parse_xml (GDataParsable *parsable, gpointer user_data, GError **error)
 
 GDataFeed *
 _gdata_feed_new_from_xml (GType feed_type, const gchar *xml, gint length, GType entry_type,
-			  GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
+                          GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
 {
 	ParseData *data;
 	GDataFeed *feed;
 
-	g_return_val_if_fail (g_type_is_a (feed_type, GDATA_TYPE_FEED) == TRUE, FALSE);
+	g_return_val_if_fail (g_type_is_a (feed_type, GDATA_TYPE_FEED), NULL);
 	g_return_val_if_fail (xml != NULL, NULL);
-	g_return_val_if_fail (g_type_is_a (entry_type, GDATA_TYPE_ENTRY) == TRUE, FALSE);
+	g_return_val_if_fail (g_type_is_a (entry_type, GDATA_TYPE_ENTRY), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	data = _gdata_feed_parse_data_new (entry_type, progress_callback, progress_user_data);
-
 	feed = GDATA_FEED (_gdata_parsable_new_from_xml (feed_type, xml, length, data, error));
-
-	_gdata_feed_parse_data_free(data);
+	_gdata_feed_parse_data_free (data);
 
 	return feed;
 }
@@ -780,6 +812,23 @@ gdata_feed_get_logo (GDataFeed *self)
 	return self->priv->logo;
 }
 
+/**
+ * gdata_feed_get_icon:
+ * @self: a #GDataFeed
+ *
+ * Returns the icon URI of the feed.
+ *
+ * Return value: the feed's icon URI, or %NULL
+ *
+ * Since: 0.6.0
+ **/
+const gchar *
+gdata_feed_get_icon (GDataFeed *self)
+{
+	g_return_val_if_fail (GDATA_IS_FEED (self), NULL);
+	return self->priv->icon;
+}
+
 /**
  * gdata_feed_get_generator:
  * @self: a #GDataFeed
@@ -867,7 +916,6 @@ _gdata_feed_parse_data_free (gpointer data)
 	g_slice_free (ParseData, data);
 }
 
-
 static gboolean
 progress_callback_idle (ProgressCallbackData *data)
 {
